<?php
/* ---------------------------------------------------------------
 *   【ffmpeg_php】を利用して、映像のサムネール画像(jpg)の作成
 *
 *    2013.05.18 作成 大角
 * --------------------------------------------------------------- */

//[ffmpeg]モジュールのロードチェック
$extension          = "ffmpeg";
$extension_soname   = $extension.'.'.PHP_SHLIB_SUFFIX;
$extension_fullname = PHP_EXTENSION_DIR . "/" . $extension_soname;
// load extension
if (!extension_loaded($extension)) {
	dl($extension_soname) or die("拡張モジュール {$extension_fullname}がロードできません\n");
}

/* -----------------
 *    初期設定
 * ----------------- */
//入力フォルダパス
$input_dir = 'mv/';
//出力フォルダパス
$output_dir= 'img_cvt/';
//サムネール画像の縮小率
$percent   = 0.5;

//処理する映像ファイル名
$inp_file  = 'cat.mpeg';
//サムネール画像ファイル名(jpg)
$out_file  = preg_replace("/\.(.+?)$/",".jpg",$inp_file);

//【絶対パスを設定しないとopen pathエラーとなる】
$movie_path = realpath($input_dir.$inp_file);

/* -----------------
 *    メイン処理
 * ----------------- */
//[ffmpeg_movie]のインスタンス生成
$movie = new ffmpeg_movie($movie_path);

//動画の幅と高さを取得
$mv_width  = $movie->getFrameWidth();
$mv_height = $movie->getFrameHeight();

//getFrameで取得するフレームNoを指定し、toGDImageでresouseを返す
$frame = $movie->getFrame(10);
$image = $frame->toGDImage();

//縮小サイズの設定
$thumb_width  = $mv_width * $percent;
$thumb_height = $mv_height * $percent;

//空の画像を作る（引数で縮小画像サイズを指定）
$new_img = Imagecreatetruecolor($thumb_width, $thumb_height);

//$imageを縮小画像サイズで$new_imgにコピー
imagecopyresampled($new_img,$image,0,0,0,0,$thumb_width,$thumb_height,$mv_width,$mv_height);

//出力用バッファの内容を消去し、出力のバッファリングをオフにする
ob_end_clean();

//---content typeヘッダをimage/jpegに設定して、jpgファイルを出力 ---//
header('Content-Type: image/jpeg');

/* できた画像を'img_cvt'フォルダに保存。
 [imageJpeg] 引数：
   画像リソース,
   ファイルの保存先のパス(NULL を設定した場合は、画像ストリームを直接出力),
   画像品質(0～100:最高、省略値：75)
*/
imageJpeg($new_img,$output_dir.$out_file,100);
//メモリを開放
imageDestroy($image);
imageDestroy($new_img);

//--- 処理した映像情報を表示 ---//
header('Content-Type: text/html');

echo "<p><img src=\"{$output_dir}{$out_file}\" alt=\"{$out_file}\"></p>";
echo "■処理ファイル名：".$movie->getFileName()."<br>";
echo "■所要時間：".ceil($movie->getDuration())." 秒<br>";
echo "■フレーム幅：".$movie->getFrameWidth()." ピクセル<br>";
echo "■フレーム高さ：".$movie->getFrameHeight()." ピクセル<br>";
echo "■フレーム数：".$movie->getFrameCount()."<br>";
echo "■フレームレート：".$movie->getFrameRate()." fps<br>";
echo "■映像コーデック：".$movie->getVideoCodec()."<br>";
printf("■音声の有無：%s<br>", $movie->hasAudio() == 0 ? 'なし' : '有り');

exit;
?>
